pytilities.overloading.test.overloaded.Storage

Package pytilities :: Package overloading :: Package test :: Module overloaded :: Class Storage |
[hide private]
[frames] | no frames]

# Class Storage

source code

    object --+
             |
            Storage

    Something with an x and y

Instance Methods | [hide private]
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__init__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Class Variables | [hide private]
| x = `1`
| y = `1`

Properties | [hide private]
Inherited from `object`: `__class__`